/****************************************************************************
 *                       Kikusui PCR-M Series AC Power Supply
 *---------------------------------------------------------------------------
 *   (c)2005 Kikusui Electronics Corp.  All Rights Reserved.         
 *---------------------------------------------------------------------------
 *                                                                          
 * Title:    kipcrm.h                                        
 * Purpose:  Kikusui PCR-M Series AC Power Supply
 *           instrument driver declarations.                                
 *                                                                          
 ****************************************************************************/

#ifndef __KIPCRM_HEADER
#define __KIPCRM_HEADER

#include <ivi.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/****************************************************************************
 *----------------- Instrument Driver Revision Information -----------------*
 ****************************************************************************/
#define KIPCRM_DRIVER_PREFIX					"kipcrm"

#define KIPCRM_MAJOR_VERSION					2     /* Instrument driver major version   */
#define KIPCRM_MINOR_VERSION					0     /* Instrument driver minor version   */
                                                                
#define KIPCRM_CLASS_SPEC_MAJOR_VERSION			1     /* Class specification major version */
#define KIPCRM_CLASS_SPEC_MINOR_VERSION			0     /* Class specification minor version */

#define KIPCRM_SUPPORTED_INSTRUMENT_MODELS		"PCR500M"
#define KIPCRM_DRIVER_VENDOR					"Kikusui"
#define KIPCRM_DRIVER_DESCRIPTION				"Kikusui PCR-M Series AC Power Supply"

/**************************************************************************** 
 *---------------------------- Attribute Defines ---------------------------* 
 ****************************************************************************/

/*- IVI Inherent Instrument Attributes ---------------------------------*/    

/* User Options */
#define KIPCRM_ATTR_RANGE_CHECK                   IVI_ATTR_RANGE_CHECK                    /* ViBoolean */
#define KIPCRM_ATTR_QUERY_INSTRUMENT_STATUS       IVI_ATTR_QUERY_INSTRUMENT_STATUS        /* ViBoolean */
#define KIPCRM_ATTR_CACHE                         IVI_ATTR_CACHE                          /* ViBoolean */
#define KIPCRM_ATTR_SIMULATE                      IVI_ATTR_SIMULATE                       /* ViBoolean */
#define KIPCRM_ATTR_RECORD_COERCIONS              IVI_ATTR_RECORD_COERCIONS               /* ViBoolean */

#define KIPCRM_ATTR_DRIVER_SETUP                  IVI_ATTR_DRIVER_SETUP                   /* ViString */
#define KIPCRM_ATTR_INTERCHANGE_CHECK             IVI_ATTR_INTERCHANGE_CHECK              /* ViBoolean */

/* Instrument Capabilities */
#define KIPCRM_ATTR_CHANNEL_COUNT                 IVI_ATTR_CHANNEL_COUNT                  /* ViInt32,  read-only  */

/* Driver Information  */
#define KIPCRM_ATTR_SPECIFIC_DRIVER_PREFIX        IVI_ATTR_SPECIFIC_DRIVER_PREFIX         /* ViString, read-only  */
#define KIPCRM_ATTR_SUPPORTED_INSTRUMENT_MODELS   IVI_ATTR_SUPPORTED_INSTRUMENT_MODELS    /* ViString, read-only  */
#define KIPCRM_ATTR_GROUP_CAPABILITIES            IVI_ATTR_GROUP_CAPABILITIES             /* ViString, read-only  */
#define KIPCRM_ATTR_INSTRUMENT_MANUFACTURER       IVI_ATTR_INSTRUMENT_MANUFACTURER        /* ViString, read-only  */
#define KIPCRM_ATTR_INSTRUMENT_MODEL              IVI_ATTR_INSTRUMENT_MODEL               /* ViString, read-only  */
#define KIPCRM_ATTR_INSTRUMENT_FIRMWARE_REVISION  IVI_ATTR_INSTRUMENT_FIRMWARE_REVISION   /* ViString, read-only  */
#define KIPCRM_ATTR_SPECIFIC_DRIVER_REVISION      IVI_ATTR_SPECIFIC_DRIVER_REVISION       /* ViString, read-only  */
#define KIPCRM_ATTR_SPECIFIC_DRIVER_VENDOR        IVI_ATTR_SPECIFIC_DRIVER_VENDOR         /* ViString, read-only  */
#define KIPCRM_ATTR_SPECIFIC_DRIVER_DESCRIPTION   IVI_ATTR_SPECIFIC_DRIVER_DESCRIPTION    /* ViString, read-only  */
#define KIPCRM_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION IVI_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION /* ViInt32, read-only */
#define KIPCRM_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION IVI_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION /* ViInt32, read-only */

/* Advanced Session Information */
#define KIPCRM_ATTR_LOGICAL_NAME                  IVI_ATTR_LOGICAL_NAME                   /* ViString, read-only  */
#define KIPCRM_ATTR_IO_RESOURCE_DESCRIPTOR        IVI_ATTR_IO_RESOURCE_DESCRIPTOR         /* ViString, read-only  */
  

/*- Instrument-Specific Attributes -------------------------------------*/

/*- Basic Instrument Operations ----------------------------------------*/

/*  viReal64    */
#define KIPCRM_ATTR_VOLTAGE_RANGE				(IVI_SPECIFIC_PUBLIC_ATTR_BASE + 1L)	/* ViReal64,  channel-based, volts */
#define KIPCRM_ATTR_VOLTAGE_LEVEL				(IVI_SPECIFIC_PUBLIC_ATTR_BASE + 2L)	/* ViReal64,  channel-based, volts */
#define KIPCRM_ATTR_CURRENT_LIMIT				(IVI_SPECIFIC_PUBLIC_ATTR_BASE + 3L)	/* ViReal64,  channel-based, amps  */
#define KIPCRM_ATTR_FREQUENCY					(IVI_SPECIFIC_PUBLIC_ATTR_BASE + 4L)	/* ViReal64,  channel-based, hertz */
#define KIPCRM_ATTR_VOLTAGE_OFFSET				(IVI_SPECIFIC_PUBLIC_ATTR_BASE + 5L)	/* ViReal64,  channel-based, volts */
#define KIPCRM_ATTR_CURRENT_OFFSET				(IVI_SPECIFIC_PUBLIC_ATTR_BASE + 6L)	/* ViReal64,  channel-based, amps  */
#define KIPCRM_ATTR_TRIGGERED_VOLTAGE_LEVEL		(IVI_SPECIFIC_PUBLIC_ATTR_BASE + 7L)    /* ViReal64,  channel-based, volts */
#define KIPCRM_ATTR_TRIGGERED_FREQUENCY			(IVI_SPECIFIC_PUBLIC_ATTR_BASE + 8L)	/* ViReal64,  channel-based, hertz  */
#define KIPCRM_ATTR_TRIGGERED_VOLTAGE_OFFSET	(IVI_SPECIFIC_PUBLIC_ATTR_BASE + 9L)	/* ViReal64,  channel-based, volts */
#define KIPCRM_ATTR_SYNC_PHASE					(IVI_SPECIFIC_PUBLIC_ATTR_BASE + 10L)	/* ViReal64,  channel-based, deg   */

/*  ViInt32	    */
#define KIPCRM_ATTR_COUPLING_MODE				(IVI_SPECIFIC_PUBLIC_ATTR_BASE + 101L)	/* ViInt32,   channel-based,	   */
#define KIPCRM_ATTR_CURRENT_LIMIT_BEHAVIOR		(IVI_SPECIFIC_PUBLIC_ATTR_BASE + 102L)	/* ViInt32,   channel-based        */
#define KIPCRM_ATTR_TRIGGER_SOURCE				(IVI_SPECIFIC_PUBLIC_ATTR_BASE + 103L)	/* ViInt32,   channel-based        */
#define KIPCRM_ATTR_HOLD_TIME					(IVI_SPECIFIC_PUBLIC_ATTR_BASE + 104L)	/* ViInt32,   channel-based        */
#define KIPCRM_ATTR_AMMETER_ITEM				(IVI_SPECIFIC_PUBLIC_ATTR_BASE + 105L)	/* ViInt32,   channel-based        */

/*  ViBoolean   */
#define KIPCRM_ATTR_OUTPUT_ENABLED				(IVI_SPECIFIC_PUBLIC_ATTR_BASE + 201L)	/* ViBoolean, channel-based        */
#define KIPCRM_ATTR_SYNC_ENABLED				(IVI_SPECIFIC_PUBLIC_ATTR_BASE + 202L)	/* ViBoolean, channel-based        */
#define KIPCRM_ATTR_AVERAGE_ENABLED				(IVI_SPECIFIC_PUBLIC_ATTR_BASE + 203L)	/* ViBoolean, channel-based        */
#define KIPCRM_ATTR_CONTINUOUS_MEASUREMENT		(IVI_SPECIFIC_PUBLIC_ATTR_BASE + 204)	/* ViBoolean, channel-based        */


/**************************************************************************** 
 *------------------------ Enumerated Values		-------------------------* 
 ****************************************************************************/

#define KIPCRM_SPECIFIC_EXT_BASE	(1000L)

#define KIPCRM_VAL_COUPLING_AC		(1)
#define KIPCRM_VAL_COUPLING_DC		(2)
#define KIPCRM_VAL_COUPLING_ACDC	(3)
#define KIPCRM_VAL_COUPLING_EXTAC	(5)
#define KIPCRM_VAL_COUPLING_EXTDC	(6)

#define KIPCRM_VAL_MEASURE_CURRENT_DC			(0)
#define KIPCRM_VAL_MEASURE_VOLTAGE_DC			(1)
#define KIPCRM_VAL_MEASURE_POWER_DC				(2)
#define KIPCRM_VAL_MEASURE_FREQUENCY			(3)
#define KIPCRM_VAL_MEASURE_CURRENT_AC			(KIPCRM_SPECIFIC_EXT_BASE + 1)
#define KIPCRM_VAL_MEASURE_CURRENT_MAX			(KIPCRM_SPECIFIC_EXT_BASE + 2)
#define KIPCRM_VAL_MEASURE_CURRENT_MAX_HOLD		(KIPCRM_SPECIFIC_EXT_BASE + 3)
#define KIPCRM_VAL_MEASURE_CURRENT_CRESTFACTOR	(KIPCRM_SPECIFIC_EXT_BASE + 4)
#define KIPCRM_VAL_MEASURE_VOLTAGE_AC			(KIPCRM_SPECIFIC_EXT_BASE + 11)
#define KIPCRM_VAL_MEASURE_POWER_AC				(KIPCRM_SPECIFIC_EXT_BASE + 21)
#define KIPCRM_VAL_MEASURE_POWER_AC_APPARENT	(KIPCRM_SPECIFIC_EXT_BASE + 22)
#define KIPCRM_VAL_MEASURE_POWER_AC_REACTIVE	(KIPCRM_SPECIFIC_EXT_BASE + 23)
#define KIPCRM_VAL_MEASURE_POWER_AC_POWERFACTOR	(KIPCRM_SPECIFIC_EXT_BASE + 24)

#define KIPCRM_VAL_OUTPUT_CONSTANT_VOLTAGE		(0)
#define KIPCRM_VAL_OUTPUT_OVER_VOLTAGE			(2)
#define KIPCRM_VAL_OUTPUT_OVER_CURRENT			(3)
#define KIPCRM_VAL_OUTPUT_UNREGULATED			(4)
#define KIPCRM_VAL_OUTPUT_DSP_ERROR				(KIPCRM_SPECIFIC_EXT_BASE + 1)
#define KIPCRM_VAL_OUTPUT_OVER_TEMPERATURE		(KIPCRM_SPECIFIC_EXT_BASE + 2)
#define KIPCRM_VAL_OUTPUT_OVER_POWER			(KIPCRM_SPECIFIC_EXT_BASE + 3)
#define KIPCRM_VAL_OUTPUT_CURRENT_OVERLOAD		(KIPCRM_SPECIFIC_EXT_BASE + 4)
#define KIPCRM_VAL_OUTPUT_POWER_OVERLOAD		(KIPCRM_SPECIFIC_EXT_BASE + 5)
#define KIPCRM_VAL_OUTPUT_CURRENT_PK_OVERLOAD	(KIPCRM_SPECIFIC_EXT_BASE + 6)
#define KIPCRM_VAL_MEASURING					(KIPCRM_SPECIFIC_EXT_BASE + 1001)
#define KIPCRM_VAL_WAITING_FOR_TRIGGER			(KIPCRM_SPECIFIC_EXT_BASE + 1002)

#define KIPCRM_VAL_CURRENT_REGULATE         (0)
#define KIPCRM_VAL_CURRENT_TRIP		        (1)

#define KIPCRM_VAL_TRIG_IMMEDIATE			(0)
#define KIPCRM_VAL_SOFTWARE_TRIG            (2) 

#define KIPCRM_VAL_HOLDTIME_SHORT			(0)
#define KIPCRM_VAL_HOLDTIME_LONG			(1)

#define KIPCRM_VAL_AMMETER_ITEM_RMS			(0)
#define KIPCRM_VAL_AMMETER_ITEM_AVERAGE		(1)
#define KIPCRM_VAL_AMMETER_ITEM_PEAK		(2)
#define KIPCRM_VAL_AMMETER_ITEM_WATTAGE		(3)


    /* Instrument specific attribute value definitions */

/**************************************************************************** 
 IVI-C inherent functions
 ****************************************************************************/

/*- Init and Close Functions -------------------------------------------*/
ViStatus _VI_FUNC  kipcrm_init(
	ViRsrc		resourceName,
	ViBoolean	IDQuery,
	ViBoolean	resetDevice,
	ViSession*	vi
);
ViStatus _VI_FUNC  kipcrm_InitWithOptions(
	ViRsrc			resourceName,
	ViBoolean		IDQuery,
	ViBoolean		resetDevice,
	ViConstString	optionString,
	ViSession*		newVi
);
ViStatus _VI_FUNC  kipcrm_close(
	ViSession	vi
);   

ViStatus _VI_FUNC  kipcrm_Disable(
	ViSession	vi
);

//ViStatus _VI_FUNC  kipcrm_GetNativeIUnknownPtr(ViSession vi, IUnknown** pNativeIUnknownPtr);
//ViStatus _VI_FUNC  kipcrm_AttachToExistingCOMSession(IUnknown* pExistingIUnknownPtr, ViSession* pVi);

/*- Coercion Info Functions --------------------------------------------*/
ViStatus _VI_FUNC  kipcrm_GetNextCoercionRecord(
	ViSession	vi,
	ViInt32		bufferSize,
	ViChar		record[]
);

/*- Interchangeability Checking Functions ------------------------------*/
ViStatus _VI_FUNC kipcrm_GetNextInterchangeWarning(
	ViSession	vi, 
	ViInt32		bufferSize,
	ViChar		warnString[]
);
ViStatus _VI_FUNC kipcrm_ResetInterchangeCheck(
	ViSession	vi
);
ViStatus _VI_FUNC kipcrm_ClearInterchangeWarnings(
	ViSession	vi
);


/*- Locking Functions --------------------------------------------------*/
ViStatus _VI_FUNC  kipcrm_LockSession(
	ViSession	vi,
	ViBoolean*	callerHasLock
);
ViStatus _VI_FUNC  kipcrm_UnlockSession(
	ViSession 	vi,
	ViBoolean*	callerHasLock
);

    /*- Error Functions ----------------------------------------------------*/
ViStatus _VI_FUNC  kipcrm_error_query(
	ViSession	vi,
	ViInt32*	errorCode,
	ViChar		errorMessage[]
);
ViStatus _VI_FUNC  kipcrm_error_message(
	ViSession	vi,
	ViStatus	errorCode,
	ViChar		errorMessage[256]
);
ViStatus _VI_FUNC  kipcrm_GetError(
	ViSession	vi,
	ViStatus*	errorCode,
	ViInt32		bufferSize,
	ViChar		description[]
);
ViStatus _VI_FUNC  kipcrm_ClearError(
	ViSession	vi
);

/*- Deprecated Error Information functions (still required by LabVIEW 6.0 when converted) -*/
ViStatus _VI_FUNC  kipcrm_GetErrorInfo (ViSession vi, ViStatus *primaryError, 
                                          ViStatus *secondaryError, 
                                          ViChar errorElaboration[256]);
ViStatus _VI_FUNC  kipcrm_ClearErrorInfo (ViSession vi);


/*- Utility Functions --------------------------------------------------*/
ViStatus _VI_FUNC  kipcrm_reset(
	ViSession	vi
);
ViStatus _VI_FUNC  kipcrm_ResetWithDefaults(
	ViSession	vi
);
ViStatus _VI_FUNC  kipcrm_InvalidateAllAttributes(
	ViSession	vi
);
ViStatus _VI_FUNC  kipcrm_self_test(
	ViSession	vi,
	ViInt16*	TestResult,
	ViChar		TestMessage[]
);
ViStatus _VI_FUNC  kipcrm_revision_query(
	ViSession	vi,
	ViChar		DriverRev[],
	ViChar		InstrRev[]
);

/*- Set, Get, Attribute Functions ----------------------------*/
ViStatus _VI_FUNC  kipcrm_GetAttributeViInt32 (ViSession vi, ViConstString channelName, ViAttr attribute, ViInt32 *value);
ViStatus _VI_FUNC  kipcrm_GetAttributeViReal64 (ViSession vi, ViConstString channelName, ViAttr attribute, ViReal64 *value);
ViStatus _VI_FUNC  kipcrm_GetAttributeViString (ViSession vi, ViConstString channelName, ViAttr attribute, ViInt32 bufSize, ViChar value[]); 
ViStatus _VI_FUNC  kipcrm_GetAttributeViSession (ViSession vi, ViConstString channelName, ViAttr attribute, ViSession *value);
ViStatus _VI_FUNC  kipcrm_GetAttributeViBoolean (ViSession vi, ViConstString channelName, ViAttr attribute, ViBoolean *value);

ViStatus _VI_FUNC  kipcrm_SetAttributeViInt32 (ViSession vi, ViConstString channelName, ViAttr attribute, ViInt32 value);
ViStatus _VI_FUNC  kipcrm_SetAttributeViReal64 (ViSession vi, ViConstString channelName, ViAttr attribute, ViReal64 value);
ViStatus _VI_FUNC  kipcrm_SetAttributeViString (ViSession vi, ViConstString channelName, ViAttr attribute, ViConstString value); 
ViStatus _VI_FUNC  kipcrm_SetAttributeViSession (ViSession vi, ViConstString channelName, ViAttr attribute, ViSession value);
ViStatus _VI_FUNC  kipcrm_SetAttributeViBoolean (ViSession vi, ViConstString channelName, ViAttr attribute, ViBoolean value);

/**************************************************************************** 
 instrument specific functions
 ****************************************************************************/




    /*- Channel Info Functions ---------------------------------------------*/
ViStatus _VI_FUNC kipcrm_GetChannelName(
	ViSession	vi,
	ViInt32		index,
	ViInt32		bufferSize,
	ViChar		name[]
);


    /*- Basic Functions ------------------------------*/

ViStatus _VI_FUNC  kipcrm_ConfigureCouplingMode(
	ViSession		vi,
	ViConstString	channelName,
	ViInt32			mode
);

ViStatus _VI_FUNC  kipcrm_ConfigureVoltageRange(
	ViSession		vi,
	ViConstString	channelName,
	ViReal64		value
);

ViStatus _VI_FUNC  kipcrm_ConfigureOutputEnabled(
	ViSession vi,
	ViConstString channelName,
	ViBoolean enabled
);

ViStatus _VI_FUNC  kipcrm_ConfigureVoltageLevel(
	ViSession		vi,
	ViConstString	channelName,
	ViReal64		value
);

ViStatus _VI_FUNC  kipcrm_ConfigureFrequency(
	ViSession		vi,
	ViConstString	channelName,
	ViReal64		value
);

ViStatus _VI_FUNC  kipcrm_ConfigureCurrentLimit(
	ViSession		vi,
	ViConstString	channelName,
	ViInt32			behaviour,
	ViReal64		value
);

ViStatus _VI_FUNC  kipcrm_ConfigureVoltageOffset(
	ViSession		vi,
	ViConstString	channelName,
	ViReal64		value
);

ViStatus _VI_FUNC  kipcrm_ConfigureCurrentOffset(
	ViSession		vi,
	ViConstString	channelName,
	ViInt32			behaviour,
	ViReal64		value
);

/* trig */

ViStatus _VI_FUNC  kipcrm_ConfigureTriggeredVoltageLevel(
	ViSession		vi,
	ViConstString	channelName,
	ViReal64		value
);

ViStatus _VI_FUNC  kipcrm_ConfigureTriggeredFrequency(
	ViSession		vi,
	ViConstString	channelName,
	ViReal64		value
);

ViStatus _VI_FUNC  kipcrm_ConfigureTriggeredVoltageOffset(
	ViSession		vi,
	ViConstString	channelName,
	ViReal64		value
);

ViStatus _VI_FUNC  kipcrm_ConfigureTriggerSource(
	ViSession		vi,
	ViConstString	channelName,
	ViInt32			source
);

/* memory */

ViStatus _VI_FUNC  kipcrm_RecallMemory(
	ViSession		vi,
	ViInt32			memoryNumber
);

ViStatus _VI_FUNC  kipcrm_StoreMemory(
	ViSession		vi,
	ViInt32			memoryNumber
);

/* misc */

ViStatus _VI_FUNC  kipcrm_ConfigureSynchronize(
	ViSession		vi,
	ViConstString	channelName,
	ViBoolean 		enabled,
	ViReal64		phase
);

ViStatus _VI_FUNC  kipcrm_ConfigureAverageEnabled(
	ViSession		vi,
	ViConstString	channelName,
	ViBoolean 		enabled
);

ViStatus _VI_FUNC  kipcrm_ConfigureHoldTime(
	ViSession		vi,
	ViConstString	channelName,
	ViInt32			holdTime
);

ViStatus _VI_FUNC  kipcrm_ConfigureAmmeterItem(
	ViSession		vi,
	ViConstString	channelName,
	ViInt32			ammeterItem
);


    /*- Action/Status ---------------------------------------------------------*/

ViStatus _VI_FUNC  kipcrm_QueryVoltageLevelMinMax(
	ViSession		vi,
	ViConstString	channelName,
	ViReal64*		min_Value,
	ViReal64*		max_Value
);

ViStatus _VI_FUNC  kipcrm_QueryFrequencyMinMax(
	ViSession		vi,
	ViConstString	channelName,
	ViReal64*		min_Value,
	ViReal64*		max_Value
);

ViStatus _VI_FUNC  kipcrm_QueryVoltageOffsetMinMax(
	ViSession		vi,
	ViConstString	channelName,
	ViReal64*		min_Value,
	ViReal64*		max_Value
);

ViStatus _VI_FUNC  kipcrm_QueryCurrentLimitMinMax(
	ViSession		vi,
	ViConstString	channelName,
	ViReal64*		min_Value,
	ViReal64*		max_Value
);

ViStatus _VI_FUNC  kipcrm_QueryCurrentOffsetMinMax(
	ViSession		vi,
	ViConstString	channelName,
	ViReal64*		min_Value,
	ViReal64*		max_Value
);

ViStatus _VI_FUNC  kipcrm_QueryOutputState(
	ViSession		vi,
	ViConstString	channelName,
	ViInt32			outputState,
	ViBoolean*		inState
);

ViStatus _VI_FUNC  kipcrm_ResetOutputProtection(
	ViSession		vi,
	ViConstString	channelName
);

ViStatus _VI_FUNC  kipcrm_ResetCurrentMaxHold(
	ViSession		vi,
	ViConstString	channelName
);

    /*- Triggering ---------------------------------------------------------*/


ViStatus _VI_FUNC  kipcrm_Abort(
	ViSession	vi
);
ViStatus _VI_FUNC  kipcrm_Initiate(
	ViSession	vi
);

ViStatus _VI_FUNC  kipcrm_SendSoftwareTrigger(
	ViSession	vi
);

    /*- Measure ---------------------------------------------------------*/

ViStatus _VI_FUNC  kipcrm_InitiateMeasurement(
	ViSession	vi,
	ViConstString	channelName
);

ViStatus _VI_FUNC  kipcrm_Fetch(
	ViSession		vi,
	ViConstString	channelName,
	ViInt32			measurementType,
	ViReal64*		measurement
);

ViStatus _VI_FUNC  kipcrm_Measure(
	ViSession		vi,
	ViConstString	channelName,
	ViInt32			measurementType,
	ViReal64*		measurement
);

ViStatus _VI_FUNC  kipcrm_ConfigureContinuousMeasure(
	ViSession		vi,
	ViConstString	channelName,
	ViBoolean 		enabled
);


ViStatus _VI_FUNC  kipcrm_WriteInstrData(
	ViSession		vi,
	ViConstString	writeBuffer
); 
ViStatus _VI_FUNC  kipcrm_ReadInstrData(
	ViSession		vi,
	ViInt32			numBytes,
	ViChar			rdBuf[],
	ViInt32*		bytesRead
);



    /*********************************************************
        Functions reserved for class driver use only.
        End-users should not call these functions.  
     *********************************************************/
/*
ViStatus _VI_FUNC  kipcrm_IviInit (ViRsrc resourceName, ViBoolean IDQuery, 
                                     ViBoolean reset, ViSession vi);
ViStatus _VI_FUNC  kipcrm_IviClose (ViSession vi);   
*/



/****************************************************************************
 *------------------------ Error And Completion Codes ----------------------*
 ****************************************************************************/
#define KIPCRM_ERROR_TRIGGER_NOT_SOFTWARE         (IVI_CROSS_CLASS_ERROR_BASE + 1L)

/****************************************************************************
 *--------- Obsolete Inherent Instrument Attributes and functions ----------*
 ****************************************************************************/
    /*- These attributes and functions have been deprecated and may not
        be supported in future versions of this driver. -*/
 
         /* Driver Information  */
#define KIPCRM_ATTR_SPECIFIC_DRIVER_MAJOR_VERSION IVI_ATTR_SPECIFIC_DRIVER_MAJOR_VERSION  /* ViInt32,  read-only  */
#define KIPCRM_ATTR_SPECIFIC_DRIVER_MINOR_VERSION IVI_ATTR_SPECIFIC_DRIVER_MINOR_VERSION  /* ViInt32,  read-only  */

        /* Error Info */
#define KIPCRM_ATTR_PRIMARY_ERROR                 IVI_ATTR_PRIMARY_ERROR                  /* ViInt32   */
#define KIPCRM_ATTR_SECONDARY_ERROR               IVI_ATTR_SECONDARY_ERROR                /* ViInt32   */
#define KIPCRM_ATTR_ERROR_ELABORATION             IVI_ATTR_ERROR_ELABORATION              /* ViString  */

        /* Advanced Session Information */
#define KIPCRM_ATTR_IO_SESSION_TYPE               IVI_ATTR_IO_SESSION_TYPE                /* ViString, read-only  */
#define KIPCRM_ATTR_IO_SESSION                    IVI_ATTR_IO_SESSION                     /* ViSession, read-only */

        /*- Deprecated Attribute Identifiers for Renamed Attributes -*/
#define KIPCRM_ATTR_NUM_CHANNELS                  KIPCRM_ATTR_CHANNEL_COUNT             /* ViInt32,  read-only  */
#define KIPCRM_ATTR_QUERY_INSTR_STATUS            KIPCRM_ATTR_QUERY_INSTRUMENT_STATUS   /* ViBoolean */
#define KIPCRM_ATTR_RESOURCE_DESCRIPTOR           KIPCRM_ATTR_IO_RESOURCE_DESCRIPTOR    /* ViString, read-only  */


/**************************************************************************** 
 *---------------------------- End Include File ----------------------------* 
 ****************************************************************************/
#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif

#endif //__KIPCRM_HEADER
